pub struct UseFloatingReturn {
pub x: UseStateHandle<f64>,
pub y: UseStateHandle<f64>,
pub placement: UseStateHandle<Placement>,
pub strategy: UseStateHandle<Strategy>,
pub middleware_data: UseStateHandle<MiddlewareData>,
pub is_positioned: UseStateHandle<bool>,
pub floating_styles: Rc<FloatingStyles>,
pub update: Callback<()>,
}Expand description
Return of use_floating.
Fields
x: UseStateHandle<f64>The x-coord of the floating element.
y: UseStateHandle<f64>The y-coord of the floating element.
placement: UseStateHandle<Placement>The stateful placement, which can be different from the initial placement passed as options.
strategy: UseStateHandle<Strategy>The strategy to use when positioning the floating element.
middleware_data: UseStateHandle<MiddlewareData>Additional data from middleware.
is_positioned: UseStateHandle<bool>Indicates if the floating element has been positioned.
floating_styles: Rc<FloatingStyles>CSS styles to apply to the floating element to position it.
update: Callback<()>The function to update floating position manually.